@@ -23,38 +23,6 @@
 ####################### HERE FOLLOW CONFIGURATION DATA #####################
 ####### TAKE CARE: JUST PARTS _IN RED_ SOULD TO BE SAFELY EDITABLE! ########
 
-@midvalues = (2, 2, 2); # POINT TO POINT CORRENSPODENCE WITH THE ABOVE, and with the variables $setvar (see below). THE MID ITERATION NUMBER FOR EACH PARAMETER. 
-# I.E. IF THERE ARE 3 ITERATION PER PARAMETER, A VALUE "2" FOR EACH $midvalue (@midvalues) HAS TO BE SPECIFIED. 
-
-# @casegroup = ( [ [5, 3], [7, 3], [9, 3] ] ) ; # BETWEEN SQUARE BRACKETS ARE THE BLOCKS OF BLOCK COORDINATE SEARCH. THE FIRST ITEM IN 
-# EACH SQUARE BRACKET IS THE POSITION OF THE FIRST ITEM IN THE ACTIVE BLOCK (INDEX FROM 0). THE SECOND ITEM IS THE DIMENSION OF THE ACTIVE BLOCK,
-# IN TERMS OF NUMBER OF PARAMETERS.
-
-$generatechance = 
-"n"; 
-# IF "n", SWEEP PATTERNS ARE TAKEN FROM $chancefile, WHERE THE SEAERCH STRUCTURES HAVE ALL EXPLICITLY SPECIFIED. IF "y", SWEEP PATTERN ARE GENERATED FROM $chanceseed.
-
-$casefile_ = 
-"./a_casefile.pl"; 
-# THIS BRINGS @casedata AND MAYBE @casegroup IF $generatechance IS SET TO "n".
-
-$chancefile_ = 
-"./a_chancefile.pl"; 
-# THIS BRINGS @chanceseriesIF $generatechance IS SET TO "n".
-
-$caseseed_ = 
-"./a_caseseed.pl"; 
-# FROM THIS @casedata AND MAYBE @casegroup ARE PRODUCED IF $generatechance IS SET TO "y", RESULTING IN A NEW $casefile.
-
-
-$chanceseed_ = 
-"./chanceseed.pl"; 
-# FROM THIS @chanceseries IS PRODUCED IF $generatechance IS SET TO "y", RESULTING IN A NEW $chancefile.
-
-$chancedata =
-"./chancedata.pl";
-# IT IS USED IF $generatechance IS SET TO "y". IT CONTAINS INFORMATIONS ABOUT THE BLOCKS TO BE GENERATED.
-
 $file = 
 "ame";  
 # Write here the root model directory.
@@ -62,7 +30,7 @@ $file =
 $filenew = "$file"."_"; 
 # Write here the work model directory.  The program will copy the root model directory into this one.  Afterward changes may be made to it
 
-@dowhat = ( # This variables tells to the program what to do.
+@dowhat = ( # This variables tell to the program what to do.
 "y", 
 # 1) create cases for simulation?
 
@@ -86,12 +54,10 @@ $filenew = "$file"."_";
 "n", 
 # 8) filter already converted reports? (NOTE: UNTESTED FROM VERSION 0.5 ON.)
 
-"n",
+"n" );  
 # 9) make table to be plotted in 3D? (NOTE: UNTESTED FROM VERSION 0.5 ON.)
 
-"n"
-); 
-# 11) checks if it is possible to launch a block search, and if it is does it.
+$optsworks = "optsworks"; # THIS SPECIFIES THE WORK DIRECTORY FOR THE OPTS MODELS. IF THIS VARIABLE IS BLANK, THE HOME DIRECTORY WILL BE USED. IF THIS VARIABLE IS NOT BLANK, OPTS  WILL WORK IN: "/home/yourhome/your_opts_work_directory/your_model_directory", which written in terms of the variables here used is: "/home/yourhome/$optsworks/$file".
 
 $preventsim = 
 "n"; 
@@ -99,67 +65,24 @@ $preventsim =
 
 $mypath = 
 "/home/ubuntu"; 
-# path of the directory in which you are going to work
+# path of the directory in which the OPT executable is.
 
 $homepath = 
 "/home/ubuntu"; 
-# path of the directory in which you are going to work, again. (OK, this redundancy has to be eliminated.)
+# path of the directory in which the OPT executable is, again. (OK, this redundancy has to be eliminated.)
 
 $fileconfig=(
 "cells.cfg"
 ); # name of the configuration file of the model, which will reside in the "./cfg/" directory in your model's directory.
 
-$outfile = "$mypath/$file-$fileconfig.feedback.txt"; 
+$outfilefeedback = "$mypath/$file-$fileconfig.feedback.txt"; 
 # Write here the name of the files in which reports will be printed. This may be useful to debug the program.  But in order to do this, you'll have to mess up with the source code to specify what you want to be printed.
 
-$outfilewrite = "$mypath/outfilewrite.csv";
-
-$toshell = 
+$outfilefeedbacktoshell = 
 "$mypath/$file-$fileconfig.feedbacktoshell.txt"; 
 # name of the files into which the output to the shell will be printed. This may be useful to check the inner working of the program, or to postpone the operations with ESP-r.  In that case, the printed has to be made executable to be launched from the shell afterward. 
 
-$exeonfiles = "y"; # say “y” if you want OPTS's work be executed on files and directories. As an alternative, you may want to say “no” because you may want to output to a shell file that you can study and make executable afterwards.
-
-my $reportfile = "$mypath/reportfile.txt";
-
-
-$simnetwork = 
-"y"; 
-# is there a mass/flow network? This information regards the simulation settings.
-
-@themereports = 
-([ "loads", "tempsstats"], [ "loads", "tempsstats"]); 
-# possibilities: "loads", "temps" , "comfort", "tempsstats" ######### General themes regarding the simulation.  This piece of information go to compose the result name files.
-
-@simtitles = 
-("mar1-apr30", "mar1-apr30" ); 
-# write here the name of the time periods will be taken into account in the simulations.
-
-@reporttitles = 
-( ["march1-31", "march1-31"], ["april1-30", "april1-30"] ); 
-# THESE ARE THE PERIODS TO BE REPORTED. THERE IS A POINT TO POINT CORRENSPONDENCE WITH @simtitles
-
-@simdata = (["1 3", "30 4", "20", "1"],["1 3", "30 4", "20", "1"]); 
-# Here put the data this way: "starting-month_1 starting-day_1", "ending-month_1 ending-day_1", "start-up-period-duration_1", "time/steps-hour_1", "starting-month_2"starting-day_2", "ending-month_2 ending-day_2", "start-up-period-duration_2", "time/steps-hour_2", ..., "starting-month_n starting-day_n", "ending-month_n ending-day_n", "start-up-period-duration_n", "time/steps-hour_n"
-# THESE ARE THE PERIODS TO BE REPORTED. THERE IS A POINT TO POINT CORRENSPONDENCE WITH @simdata
-
-
-@retrievedata = ( 
-[["1 3 1", "31 3 24", "1"] , ["1 3 1", "31 3 24", "1"]], [["1 4 1", "30 4 24", "1"] , ["1 4 1", "30 4 24", "1"]]
-); 
-# start data to retrieve for temps; end data to retrieve for temps.
-# THESE ARE THE PERIODS TO BE REPORTED. THERE IS A POINT TO POINT CORRENSPONDENCE WITH @reporttiles# THESE ARE THE PERIODS TO BE REPORTED. THERE IS A POINT TO POINT CORRENSPONDENCE WITH @simdata# THESE ARE THE PERIODS TO BE REPORTED. THERE IS A POINT TO POINT CORRENSPONDENCE WITH @simdata
-
-@keepcolumns = ( [1, 6], [16, 18] ); 
-# COLUMNS TO KEEP FROM THE FILE OF RESULTS. THEY ARE WRITTEN IN PAIRS. 
-# THE FIRST ITEM OF EACH PAIR IS THE OBJECTIVE FUNCTION NAME AND THE SECOND IS THE OBJECTIVE FUNCTION.
-
-@weights = ( 0.5, 0.5); 
-# RATIO OF EACH OBJECTIVE FUNCTION, OVER THE TOTAL OF 1.
-
-@weightsaim = (1, -1); 
-# THERE IS A POINT TO POINT CORRENSPONDENCE WITH THE ABOVE ARRAY. A (-1) VALUE TELLS THE PROGRAM THAT THE OBJECTIVE FOR THAT OBJECTIVE FUNCTION IS MINIMIZATION. 
-# A (+1) VALUE TELLS THE PROGRAM THAT THE OBJECTIVE IS MAXIMIZATION. 
+$exeonfiles = “y”; # say “y” if you want OPTS's work be executed on files and directories. As an alternative, you may want to say “no” because you may want to output to a shell file that you can study and make executable afterwards.
 
 @varthemes_report = (
 "rotation_zy", "rotation_xy","albedo_terrace", "albedo_side_wall"
@@ -173,6 +96,50 @@ $simnetwork =
 5, 5, 5, 5, 5
 );  ######### Number of steps allowed for each variables. In the same order above. (NOTE: THIS OPERATION MAY OFTEN  BE UNUSED.)
 
+@themereports = (
+"tempsstats"
+); # possibilities:  "temps", "comfort", "loads", or "tempsstats" ######### General themes regarding the simulation.  This piece of information go to compose the result name files.
+
+@simtitle = (
+"aug01-aug31"
+); # write here the name of the time periods to be taken into account in the simulations.
+
+@simdata=(
+"01 08", "31 8", "20", "1"
+); # Time data for simulations. Here put the data this way: "starting-month_1 starting-day_1", "ending-month_1 ending-day_1", "start-up-period-duration_1", "time/steps-hour_1"
+
+$simnetwork = 
+"y"; 
+# is there a mass/flow network? This information regards the simulation settings.
+
+@retrievedata = ( # CHOOSE ONE. [NOW UNTESTED?]
+"n", 
+# retrieve temperature results?
+
+"n", 
+# retrieve comfort results?
+
+"n", 
+# retrieve loads results? 
+
+"y"); 
+# retrieve temp-stats results?
+
+@retrievedatatemps = (
+"1 08 1", "31 08 24", "1"
+); # start data to retrieve for temperature reports; end data to retrieve for temperature reports.
+
+@retrievedatacomfort = (
+"1 08 1", "31 08 24" , "1"
+); # start data to retrieve for comfort reports; end data to retrieve for comfort reports.
+
+@retrievedataloads = (
+"01 02 1", "28 2 24", "1"
+); # start data to retrieve for load-stats reports; end data to retrieve for load-stats reports.
+
+@retrievedatatempsstats = (
+"1 08 1", "31 08 24", "1"
+); # start data to retrieve for temp-stats reports; end data to retrieve for temp-stats reports.
 
 @rankdata = (
 "n", "n", "n", "y"
@@ -212,6 +179,11 @@ $reportloadsdata = [[$simtitle[0], $simtitle[1]],
 
 ################# HERE THE MORPHING VARIABLES FOLLOW ###################
 
+@varnumbers = (
+ 1, 2 
+);   #  THIS DATUM IS OF THE GREATEST IMPORTANCE. IT SPECIFIES THE CYCLE SEQUENCE. THE NUMBERS MENTION THE VARIABLES TO BE CHECKED. EXAMPLE: (1, 10, 5, 2, 4.)
+
+
 ############################## HERE FOLLOWS THE DESCRIPTION OF MORPHING PHASE 1. 
 $stepsvar1 =
 3
@@ -667,9 +639,6 @@ $keep_obstructions1 = ##### BRING SOME OBSTRUCTIONS BACK IN THE ORIGINAL POSITIO
 # TYPICALLY, IT WILL BE USED FOR A ZONE, BUT NOTHING PREVENTS THAT SEVERAL OF THEM CHAINED ONE AFTER 
 # THE OTHER ARE APPLIED TO THE SAME ZONE.
 # $counterstep, WHICH TELLS THE PROGRAM WHAT THE CURRENT ITERATION STEP IS.
-# If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-# WITH THE FOLLOWING VARIABLE: @vertexletters
-
 
 @constrain_controls1 = ( # to apply contraints to and from controls.
 ["y", # apply constraints to controls? "y" or "n".
@@ -707,8 +676,7 @@ $keep_obstructions1 = ##### BRING SOME OBSTRUCTIONS BACK IN THE ORIGINAL POSITIO
 # TYPICALLY, IT WILL BE USED FOR A ZONE, BUT NOTHING PREVENTS THAT SEVERAL OF THEM CHAINED ONE AFTER 
 # THE OTHER ARE APPLIED TO THE SAME ZONE.
 # $counterstep, WHICH TELLS THE PROGRAM WHAT THE CURRENT ITERATION STEP IS.
-# If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-# WITH THE FOLLOWING VARIABLES: @letters AND @period_letters
+
 
 @constrain_obstructions1 = ( # To apply constraints to and from obstructions.
  ["y", # apply constraints to obstructions? "y" or "n".
@@ -742,8 +710,7 @@ $keep_obstructions1 = ##### BRING SOME OBSTRUCTIONS BACK IN THE ORIGINAL POSITIO
 # TYPICALLY, IT WILL BE USED FOR A ZONE, BUT NOTHING PREVENTS THAT SEVERAL OF THEM CHAINED ONE AFTER 
 # THE OTHER ARE APPLIED TO THE SAME ZONE.
 # $counterstep, WHICH TELLS THE PROGRAM WHAT THE CURRENT ITERATION STEP IS.
-# If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-# WITH THE FOLLOWING VARIABLE:  @obs_letters 
+
 
 @vary_net1 = ( [
 "/nets/cell.afn", # source file
@@ -796,9 +763,7 @@ $keep_obstructions1 = ##### BRING SOME OBSTRUCTIONS BACK IN THE ORIGINAL POSITIO
 [unused], # OPTIONAL. THIRD SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE.
 [unused], # OPTIONAL. FOURTH SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE.
 [unused] # OPTIONAL. FIFTH SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE. YOU CAN ADD NEW SEQUENCES.
-); # If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-# WITH THE FOLLOWING VARIABLES:
-# @node_letters AND @component_letters 
+);
 
 
 @constrain_net1 = (
@@ -850,9 +815,7 @@ $keep_obstructions1 = ##### BRING SOME OBSTRUCTIONS BACK IN THE ORIGINAL POSITIO
 # TYPICALLY, IT WILL BE USED FOR A ZONE, BUT NOTHING PREVENTS THAT SEVERAL OF THEM CHAINED ONE AFTER 
 # THE OTHER ARE APPLIED TO THE SAME ZONE.
 # $counterstep, WHICH TELLS THE PROGRAM WHAT THE CURRENT ITERATION STEP IS.
-# If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-# WITH THE FOLLOWING VARIABLES: @vertexletters (FOR GEOMETRY EDITING), @obs_letters (FOR OBSTRUCTIONS), 
-# @node_letters AND @component_letters (FOR NETS), @letters AND @period_letters (FOR CONTROLS)
+
 
 @propagate_constraints1 = (
 ["y", # apply constraints to nets? "y" or "n".
@@ -974,11 +937,6 @@ $keep_obstructions1 = ##### BRING SOME OBSTRUCTIONS BACK IN THE ORIGINAL POSITIO
 # 11) $flow_control[$countflow][$countflowcontrol][$flow_fraction] # Same as above.
 # EXAMPLE : $flow_control[1][2][$flow_fraction] = 0.7
 # OTHER EXAMPLE: $flow_control[1][2][$flow_fraction] = $flow_control[2][1][$flow_fraction]
-# If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-# WITH THE FOLLOWING VARIABLES: @vertexletters (FOR GEOMETRY EDITING), @obs_letters (FOR OBSTRUCTIONS), 
-# @node_letters AND @component_letters (FOR NETS), @letters AND @period_letters (FOR CONTROLS)
-# FINALLY, ALL THE VARIABLES SPECIFIED IN THIS FILE CAN BE ACCESSED. FOR EXAMPLE: $recalculateish1, $translate2, ETC.
-# THE VARIABLE AT THE CURRENT SEARCH STEP CAN BE NAMED WITHOUT THE NUMBER. EXAMPLE: $recalculateish, $translate, ETC.
 
 
 $recalculateish1 = 
@@ -1021,23 +979,8 @@ $recalculateish1 =
 ); #
 
 
-$skip1 = " if ( ($$translate[$counterzone][2][0] > 2) or ($$translate[$counterzone][2][0] < 8 ) ) "; 
-# THIS IS AN EXAMPLE OF CONDITION TO SKIP SOME TESTS. THIS IS A CONDITION WRITTEN IN PERL AND CAN BE AS COMPLEX AS YOU WANT.
-# IT WILL BE EVALED BY THE PROGRAM TO SKIP AN INSTANCE IF CONDITION YOU HAVE SPECIFIED IS MET.
 
 
-$constrain1 = "
-if ( ($$translate[$counterzone][2][0] > 2) or ($$translate[$counterzone][2][0] < 8 ) ) { $something1 = $something2 ; } 
-"; # perl instructions for propagation of constraints can be specified here.
-# All the variables here specified in the comments to "@propagate_constraints" can be used,
-# If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-# WITH THE FOLLOWING VARIABLES: @vertexletters (FOR GEOMETRY EDITING), "@obs_letters" (FOR OBSTRUCTIONS), 
-# "@node_letters" AND "@component_letters" (FOR NETS), "@letters" AND "@period_letters" (FOR CONTROLS)
-# To propagate dhe constraints, the "$constrain" variable must be used together with an operation
-# activated by the existence of a file for propagation of constraints, even if that file is void.
-# But even if such a file is no void, the condition specified in the variable "$constrain"
-# will be able to access and modify all the variables in the present OPTS condifuration file, as
-# for example "$traslate2", or "$translate" (when referred to the current iteration).
 
 ############################## HERE FOLLOWS THE DESCRIPTION OF MORPHING PHASE NUMBER 2. ##########################
 $stepsvar2 =
@@ -1099,10 +1042,6 @@ $translate2 =  [ [  #####  @applytype1 = (["translation", "file_name.geo", "targ
 [unused] # OPTIONAL. FIFTH SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE.
 ];
 
-$skip2 = ""; 
-# THIS IS AN EXAMPLE OF CONDITION TO SKIP SOME TESTS. THIS IS A CONDITION WRITTEN IN PERL AND CAN BE AS COMPLEX AS YOU WANT.
-# IT WILL BE EVALED BY THE PROGRAM TO SKIP AN INSTANCE IF CONDITION YOU HAVE SPECIFIED IS MET. NONE, IN THIS CASE
-
 ### … AND SO ON FOR ALL THE OTHER VARIABLES AND SEARCH CYCLE NUMBERS. ALL ONE HAVE TO DO IS CHANGE THE NUMBER OF THE VARIABLES FOR EACH CYCLE. (EXAMPLE: @applytype1 FOR CYCLE 1, @applytype2 FOR CYCLE TO, AND SO ON.) AND IF IN A CERTAIN CYCLE A VARIABLE IS NOT USED, IT HAS NOT TO BE SPECIFIED. JUST FEW VARIABLE ARE MANDATORY FOR EACH CYCLE: $stepsvar, @applytype and $general_variables . THE ORDER OF THE CYCLES TO BE FOLLOWED IS SPECIFIED BY @varnumbers .
 
 1; # <- LEAVE THIS “1! HERE.
